@@ -753,3 +753,10 @@ void concProbKendall(double *data, int *nSite, int *nObs, double *concProb,
 void rbrownexact(double *coord, int *nObs, int *nSite, int *dim,
 		 int *grid, double *range, double *smooth,
 		 double *ans);
+void rextremaltexact(double *coord, int *nObs, int *nSite, int *dim,
+		     int *covmod, int *grid, double *nugget, double *range,
+		     double *smooth, double *DoF, double *ans);
+void rschlatherexact(double *coord, int *nObs, int *nSite, int *dim,
+		     int *covmod, int *grid, double *nugget, double *range,
+		     double *smooth, double *ans);
+
